<?php

namespace Teknisa\MAN\Utilities;

use Utilities\Utilities;
use NFePHP\Common\Files\FilesFolders;

class NfceConfigCreator{

    public function createConfig($data, $fileName, $filePath){
        // --- Creates print preferences
        $aDocFormat = self::createDocFormat($data);

        // --- Defines the mail which sends and receives the XML's 
        $aMailConf = self::createMailConf($data);

        // --- Creates proxy configuration (Only if the ambient requires it)
        $aProxyConf = self::createProxyConf($data);

        // --- Creates the main parameters
        $aConfig = self::createParameters($data);
        $aConfig['aDocFormat'] = $aDocFormat;
        $aConfig['aMailConf'] = $aMailConf;
        $aConfig['aProxyConf'] = $aProxyConf;

        // --- Creates the config path
        $configPath = $filePath.DIRECTORY_SEPARATOR."config".DIRECTORY_SEPARATOR;
        $configName = $fileName.".json";


        // --- Convert the array to Json
        $content = self::convertToJson($aConfig);

        // --- Saves the file
        $status = self::createFile($content, $configPath, $configName);

        return $status;
    }

    public function createDocFormat($data){
        $aDocFormat = array(
            'format' => isset($data['format']) ? $data['format'] : "P",    
            'paper' => isset($data['paper']) ? $data['paper'] : "A4",  
            'southpaw' => isset($data['southpaw']) ? $data['southpaw'] : true, 
            'pathLogoFile' => isset($data['pathLogoFile']) ? $data['pathLogoFile'] : "",   
            'logoPosition' => isset($data['logoPosition']) ? $data['logoPosition'] : "L",  
            'font' => isset($data['font']) ? $data['font'] : "Times",  
            'printer' => isset($data['printer']) ? $data['printer'] : ""
        );

        return $aDocFormat;   
    }

    public function createMailConf($data){
        $aMailConf = array(
            'mailAuth' => isset($data['mailAuth']) ? $data['mailAuth'] : true,
            'mailFrom' => isset($data['mailFrom']) ? $data['mailFrom'] : "",
            'mailSmtp' => isset($data['mailSmtp']) ? $data['mailSmtp'] : "",
            'mailUser' => isset($data['mailUser']) ? $data['mailUser'] : "",
            'mailPass' => isset($data['mailPass']) ? $data['mailPass'] : "",
            'mailProtocol' => $data['mailProtocol'] == "none" ? $data['mailProtocol'] : "",
            'mailPort' => isset($data['mailPort']) ? $data['mailPort'] : "",
            'mailFromMail' => isset($data['mailFromMail']) ? $data['mailFromMail'] : "",
            'mailFromName' => isset($data['mailFromName']) ? $data['mailFromName'] : "",
            'mailReplayToMail' => isset($data['mailReplayToMail']) ? $data['mailReplayToMail'] : "",
            'mailReplayToName' => isset($data['mailReplayToName']) ? $data['mailReplayToName'] : "",
            'mailImapHost' => isset($data['mailImapHost']) ? $data['mailImapHost'] : "",
            'mailImapPort' => isset($data['mailImapPort']) ? $data['mailImapPort'] : "",
            'mailImapSecurity' => isset($data['mailImapSecurity']) ? $data['mailImapSecurity'] : "",
            'mailImapNocerts' => isset($data['mailImapNocerts']) ? $data['mailImapNocerts'] : "",
            'mailImapBox' => isset($data['mailImapBox']) ? $data['mailImapBox'] : ""
        );

        return $aMailConf;
    }

    public function createProxyConf($data){  
        $aProxyConf = array(
            'proxyIp' => isset($data['proxyIp']) ? $data['proxyIp'] : "",
            'proxyPort' => isset($data['proxyPort']) ? $data['proxyPort'] : "",
            'proxyUser' => isset($data['proxyUser']) ? $data['proxyUser'] : "",
            'proxyPass' => isset($data['proxyPass']) ? $data['proxyPass'] : ""
        );

        return $aProxyConf;
    }

    public function createParameters($data){        
        $atualizacao = date('Y-m-d h:i:s');

        $aConfig = array(
            'atualizacao' => $atualizacao,
            'tpAmb' => isset($data['tpAmb']) ? $data['tpAmb'] : "P", 
            'pathXmlUrlFileNFe' => isset($data['pathXmlUrlFileNFe']) ? $data['pathXmlUrlFileNFe'] : "A4",    
            'pathXmlUrlFileCTe' => isset($data['pathXmlUrlFileCTe']) ? $data['pathXmlUrlFileCTe'] : true,    
            'pathXmlUrlFileMDFe' => isset($data['pathXmlUrlFileMDFe']) ? $data['pathXmlUrlFileMDFe'] : "",   
            'pathXmlUrlFileCLe' => isset($data['pathXmlUrlFileCLe']) ? $data['pathXmlUrlFileCLe'] : "",  
            'pathXmlUrlFileNFSe' => isset($data['pathXmlUrlFileNFSe']) ? $data['pathXmlUrlFileNFSe'] : "",   
            'pathNFeFiles' => isset($data['pathNFeFiles']) ? $data['pathNFeFiles'] : "",
            'pathCTeFiles' => isset($data['pathCTeFiles']) ? $data['pathCTeFiles'] : "",
            'pathMDFeFiles' => isset($data['pathMDFeFiles']) ? $data['pathMDFeFiles'] : "",
            'pathCLeFiles' => isset($data['pathCLeFiles']) ? $data['pathCLeFiles'] : "",
            'pathNFSeFiles' => isset($data['pathNFSeFiles']) ? $data['pathNFSeFiles'] : "",
            'pathCertsFiles' => isset($data['pathCertsFiles']) ? $data['pathCertsFiles'] : "",
            'siteUrl' => isset($data['siteUrl']) ? $data['siteUrl'] : "",
            'schemesNFe' => isset($data['schemesNFe']) ? $data['schemesNFe'] : "PL_008f",
            'schemesCTe' => isset($data['schemesCTe']) ? $data['schemesCTe'] : "PL_CTe_200",
            'schemesMDFe' => isset($data['schemesMDFe']) ? $data['schemesMDFe'] : "PL_MDFe_100",
            'schemesCLe' => isset($data['schemesCLe']) ? $data['schemesCLe'] : "",
            'schemesNFSe' => isset($data['schemesNFSe']) ? $data['schemesNFSe'] : "",
            'razaosocial' => isset($data['razaosocial']) ? $data['razaosocial'] : "",
            'siglaUF' => isset($data['siglaUF']) ? $data['siglaUF'] : "SP",
            'cnpj' => isset($data['cnpj']) ? $data['cnpj'] : "",
            'tokenIBPT' => isset($data['tokenIBPT']) ? $data['tokenIBPT'] : "",
            'tokenNFCe' => isset($data['tokenNFCe']) ? $data['tokenNFCe'] : "",
            'tokenNFCeId' => isset($data['tokenNFCeId']) ? $data['tokenNFCeId'] : "",
            'certPfxName' => isset($data['certPfxName']) ? $data['certPfxName'] : "",
            'certPassword' => isset($data['certPassword']) ? $data['certPassword'] : "",
            'certPhrase' => isset($data['certPhrase']) ? $data['certPhrase'] : ""
        );

        return $aConfig; 
    }

    public function convertToJson($aConfig){
        $content = json_encode($aConfig);
        return $content;
    }

    public function createFile($content, $configPath, $configName){
        if(Utilities::createFolder($configPath)){   
            $response = FilesFolders::saveFile($configPath, $configName, $content);
            if($response){
                return ["Arquivo criado com sucesso!", "success"];
            }else{
                return ["Erro ao criar o arquivo!", "error"];
            }
        }else{
            return ["Erro ao criar o arquivo!", "error"];
        }
    }

}